@@ -1,7 +1,7 @@
 #
 
 
-__author__ = 'Kael Zhang'
+__author__ = 'Kael Zhang <i@kael.me>'
 
 import json
 import hashlib
@@ -86,6 +86,16 @@ class Neuron(object):
         self._csses.add(css_module)
         return ''
 
+    def src(self, module_id):
+        name, range_, path = module.parse_module_id(module_id)
+        if name not in self.dependency_tree:
+            version = range_
+        else:
+            versions = self.dependency_tree[name]
+            version = module.max_satisfying(range_, versions.keys())
+
+        return self.resolve(module.module_id(name, version, path))
+
     def output_css(self):
         self.analyze()
 
@@ -113,7 +123,11 @@ class Neuron(object):
 
         return self._get_joiner().join([
             self._output_neuron(),
-            self._output_scripts(),
+            self._output_scripts()
+        ])
+
+    def output_config(self):
+        return self._get_joiner().join([
             '<script>',
             self._output_config(),
             '</script>'
